@@ -1,6 +1,7 @@
 import contextlib
 import os
 import sys
+import shutil
 
 
 class Folder():
@@ -12,5 +13,11 @@ class Folder():
         with contextlib.suppress(FileExistsError):
             os.mkdir(self.path)
 
+    def move(self, new_path: str):
+        shutil.move(self.path, new_path)
+
     def exists(self) -> bool:
-        return os.path.isdir(self.path)
\ No newline at end of file
+        return os.path.isdir(self.path)
+
+    def delete(self):
+        shutil.rmtree('/folder_name', ignore_errors=True)
\ No newline at end of file
